@@ -82,6 +82,7 @@ class RosResourcePlugin(UnilintPlugin):
         return result
 
 
+#pylint: disable=R0921
 class AbstractRosPlugin(UnilintPlugin):
     """Defines a plugin that depends on the categories of RosResourcePlugin"""
 
@@ -91,3 +92,10 @@ class AbstractRosPlugin(UnilintPlugin):
     @classmethod
     def get_depends(cls):
         return ROS_SOURCE
+
+    @classmethod
+    def get_id(cls):
+        """
+        :returns: short lowercase string
+        """
+        raise NotImplementedError('get_id not implemented by Plugin class')
