@@ -27,6 +27,8 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
+'common helpers for unilint code and plugins'
+
 import os
 import re
 import logging
@@ -35,6 +37,7 @@ import copy
 
 
 class UnilintException(Exception):
+    '''General Exception for unilint code'''
     pass
 
 
@@ -55,6 +58,7 @@ def is_binary(filename):
 
 
 def is_script(path):
+    '''heuristically decide whether file is a script'''
     return (re.match('^#|.*~$|^_|^\.', os.path.basename(path)) is None and
             not is_binary(path))
 
@@ -68,11 +72,12 @@ def run_shell_command(cmd,
                       ignore_returncodes=None,
                       capture_std_err=False):
     """
-    executes a command and hides the stdout output, loggs
-    stderr output when command result is not zero. Make sure to sanitize arguments in the command.
+    executes a command and hides the stdout output, loggs stderr
+    output when command result is not zero. Make sure to sanitize
+    arguments in the command.
 
     :param cmd: A string to execute.
-    :param shell: Whether to use os shell, this is DANGEROUS, as vulnerable to shell injection.
+    :param shell: use os shell, this is vulnerable to shell injection.
     :returns: ( returncode, stdout, stderr)
     :raises: OSError
     """
