@@ -28,7 +28,6 @@
 # POSSIBILITY OF SUCH DAMAGE.
 
 from __future__ import print_function
-import os
 import re
 from unilint.cpp_source_plugin import AbstractCppPlugin
 from unilint.unilint_plugin import UnilintPluginInitException
@@ -38,6 +37,10 @@ from unilint.issue import Issue
 PROGRESS_PATTERN = re.compile('^[0-9]+/[0-9]')
 
 __pychecker__ = '--unusednames=cls,options,subdirs'
+_IGNORED_PREFIXES = [
+    'Cppcheck - ',
+    "Checking ",
+    "::missingInclude:Cppcheck cannot find all the include file"]
 
 
 class CppcheckPlugin(AbstractCppPlugin):
@@ -104,8 +107,7 @@ class CppcheckPlugin(AbstractCppPlugin):
             ignore = False
             if line.strip() == '':
                 continue
-            for prefix in ['Cppcheck - ', "Checking ",
-                           "::missingInclude:Cppcheck cannot find all the include file"]:
+            for prefix in _IGNORED_PREFIXES:
                 if line.startswith(prefix):
                     ignore = True
                     break
