@@ -32,14 +32,15 @@ from string import Template
 from unilint.common import UnilintException
 
 FILENAME = 'f'
-RELPATH =  'F'
-MESSAGE =  'M'
-LINE =     'L'
+RELPATH = 'F'
+MESSAGE = 'M'
+LINE = 'L'
 POSITION = 'P'
-CHECKER =  'C'
-TYPE =     'T'
+CHECKER = 'C'
+TYPE = 'T'
 SEVERITY = 'S'
-FLAGSYMBOLS = [FILENAME, RELPATH, MESSAGE, LINE, POSITION, CHECKER, TYPE, SEVERITY]
+FLAGSYMBOLS = [FILENAME, RELPATH, MESSAGE, LINE, POSITION, CHECKER, TYPE,
+               SEVERITY]
 FLAGS = ['$%s' % flag_temp for flag_temp in FLAGSYMBOLS]
 
 
@@ -53,7 +54,8 @@ def print_formatted(format_template, issue_list, basepath):
             flag_provided = True
             break
     if not flag_provided:
-        raise UnilintException("No known flags provided : %s" % format_template)
+        raise UnilintException(
+            "No known flags provided : %s" % format_template)
 
     template = Template(format_template)
 
