@@ -58,7 +58,8 @@ class PycheckerPlugin(AbstractPythonPlugin):
                                                 ignore_returncodes=[127])
         if value == 0:
             return "pychecker: %s" % output
-        raise UnilintPluginInitException("ERROR Cannot find pychecker, install via apt or pip\n%s" % message)
+        raise UnilintPluginInitException(
+            "ERROR Can't find pychecker, install via apt or pip\n%s" % message)
 
     def check_resource(self, options, path, type_categories):
         if not 'python-src' in type_categories and \
@@ -89,8 +90,8 @@ class PycheckerPlugin(AbstractPythonPlugin):
     def parse(self, output):
         issues = []
         # Example output
-        # /home/kruset/work/fuerte/unilint/src/unilint/pychecker_plugin.py:13: Local variable (pythonfound) not used
-        # /home/kruset/work/fuerte/unilint/src/unilint/pychecker_plugin.py:47: No global (Issue) found
+        # /tmp/unilint/plugin.py:13: Local variable (pythonfound) not used
+        # /tmp/unilint/pychecker_plugin.py:47: No global (Issue) found
 
         for line in output.splitlines():
             ignore = False
