@@ -64,6 +64,7 @@ class PythonSourcePlugin(UnilintPlugin):
         return result
 
 
+#pylint: disable=R0921
 class AbstractPythonPlugin(UnilintPlugin):
     """Defines a plugin that depends on the categories of PythonSourcePlugin"""
     def __init__(self, shell_function):
@@ -72,3 +73,10 @@ class AbstractPythonPlugin(UnilintPlugin):
     @classmethod
     def get_depends(cls):
         return [PY_SOURCE]
+
+    @classmethod
+    def get_id(cls):
+        """
+        :returns: short lowercase string
+        """
+        raise NotImplementedError('get_id not implemented by Plugin class')
