@@ -46,9 +46,10 @@ def register_standard_formatters():
                 loc_str = os.path.relpath(issuepath, basepath)
             else:
                 loc_str = issuepath
-            location = "%s :%s:%s:" % (loc_str,
-                                       str(issue.line_number_start or '').ljust(3),
-                                       str(issue.line_position or '').ljust(3))
+            location = ("%s :%s:%s:" %
+                        (loc_str,
+                         str(issue.line_number_start or '').ljust(3),
+                         str(issue.line_position or '').ljust(3)))
             location = location.ljust(20)
             sys.stdout.write("%s   %s\n" % (location, issue.message))
 
