@@ -27,9 +27,12 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
+"contains main function and helpers"
+
 from __future__ import print_function
 import os
 import sys
+import logging
 from argparse import ArgumentParser
 
 from unilint.__version__ import VERSION
@@ -117,7 +120,9 @@ def resolve_plugins(selected_plugins_string,
         if deps is not None:
             for dep in deps:
                 if not dep in PLUGINS:
-                    raise UnilintException('Unknown plugin dependency: %s of %s' % (dep, plugin_id))
+                    raise UnilintException(
+                        'Unknown plugin dependency: %s of %s' %
+                        (dep, plugin_id))
                 if not dep in result_plugin_ids and not dep in dependencies:
                     dependencies.append(dep)
     for dep_id in dependencies:
@@ -129,10 +134,20 @@ def resolve_plugins(selected_plugins_string,
             selected_plugins[plugin_id] = PLUGINS[plugin_id](run_shell_command)
         except UnilintPluginInitException as upie:
             if not quiet:
-                print("plugin %s failed to activate: %s" % (plugin_id, str(upie)))
+                print("plugin %s failed to activate: %s" %
+                      (plugin_id, str(upie)))
     return selected_plugins
 
 
+def index_different(id1, id2):
+    '''quick check returning true only if both values as ints are equal'''
+    if not id1 or not id2:
+        return False
+    if int(id1) != int(id2):
+        return True
+    return False
+
+
 def remove_duplicates(issues):
     """
     looks for lines in list of issues having the same line number and
@@ -146,31 +161,32 @@ def remove_duplicates(issues):
     sameline_issues = []
     lastline = -1
     lastcolumn = -1
+
     for issue in issues2:
-        if (issue.line_number_start != lastline) or \
-                (issue.line_position != lastcolumn and
-                 (issue.line_position is None or int(issue.line_position) >= 0) and
-                 lastcolumn >= 0):
+        is_likely_duplicate = True
+        if (index_different(issue.line_number_start, lastline)):
+            is_likely_duplicate = False
+        elif (index_different(issue.line_position, lastcolumn)):
+            is_likely_duplicate = False
+
+        if not is_likely_duplicate:
             sameline_issues = []
-            lastline = issue.line_number_start
-            if lastline:
-                lastline = int(lastline)
-            lastcolumn = issue.line_position or -1
-            if lastcolumn:
-                lastcolumn = int(lastcolumn)
+            lastline = int(issue.line_number_start or -1)
+            lastcolumn = int(issue.line_position or -1)
         else:
+            # check whether new issue is a duplicate
             is_duplicate = False
             for oldissue in sameline_issues:
                 # for now, will rely on manually crafted duplicate
                 # detection for similar error in different code analysers
-                for keyword_vector in [('too long', ),
-                                       ('indentation contains', ),
-                                       ('variable ', ),
-                                       ('not used', 'unused'),
-                                       ('one statement', 'multiple statements')]:
-                    for keyword_match_old in keyword_vector:
+                for keyword_vec in [('too long', ),
+                                    ('indentation contains', ),
+                                    ('variable ', ),
+                                    ('not used', 'unused'),
+                                    ('one statement', 'multiple statements')]:
+                    for keyword_match_old in keyword_vec:
                         if keyword_match_old in oldissue.message:
-                            for keyword_match in keyword_vector:
+                            for keyword_match in keyword_vec:
                                 if keyword_match in issue.message:
                                     is_duplicate = True
                                     break
@@ -202,7 +218,9 @@ def order_issues(issues):
     :param issues: list of Issue
     """
     def keyfun(iss):
-        return "%s%sz%s" % (iss.path, str(iss.line_number_start).rjust(5, '0'), str(iss.line_position).rjust(3, '0'))
+        return "%s%sz%s" % (iss.path,
+                            str(iss.line_number_start).rjust(5, '0'),
+                            str(iss.line_position).rjust(3, '0'))
     if not issues:
         return issues
     return sorted(issues, key=keyfun)
@@ -221,15 +239,12 @@ def check_path(path_to_check,
     """
     runs all selected plugins on the given files in order,
     optionally printing issue messages as soon as available
-    :param path_to_check: path to file or folder in which to run checks on files
+    :param path_to_check: path to file/folder in which to run checks on files
     :param basepath: absolute path that user gave in cli
     :param args: all CLI argument
     :param subdirs: subdirectories
     :param files: the files to check
     """
-    if not os.path.exists(path_to_check):
-        print('Ignoring argument that does not exist: %s' % path_to_check)
-        return
     categorized_resources = {}
     for plugin in args.selected_plugins.values():
         new_categories = \
@@ -258,8 +273,8 @@ def check_path(path_to_check,
             continue
         if 'backup' in categories:
             continue
-        if args.debug:
-            print("processing: %s as %s" % (resource, categories))
+        log = logging.getLogger(__name__)
+        log.debug("processing: %s as %s" % (resource, categories))
         for plugin in args.selected_plugins.values():
             try:
                 result = plugin.check_resource(args,
@@ -270,18 +285,40 @@ def check_path(path_to_check,
                     # get the output to the user as quickly as possible
                     print_issues(args, result, basepath)
             except KeyboardInterrupt as kbi:
-                raise UnilintException('Interrupted while running %s on %s: %s' % (plugin.get_id(), resource, kbi))
+                raise UnilintException(
+                    'Interrupted while running %s on %s: %s' %
+                    (plugin.get_id(), resource, kbi))
         if resource_issues:
             resource_issues = remove_duplicates(resource_issues)
             extend_maybe(issues, resource_issues)
             if args.ordered and not args.raw:
                 # print here unless we already printed
-                resource_issues = order_issues(resource_issues)
+                resource_issues = resource_issues
                 print_issues(args, resource_issues, basepath)
     return issues
 
 
+def get_pythonpath(path):
+    '''applies heuristics like nose to conveniently set the PYTHONPATH'''
+    if not os.path.exists(os.path.dirname(path)):
+        return ''
+    if not os.path.isdir(path) or \
+            os.path.isfile(os.path.join(path, '__init__.py')):
+        if not os.path.dirname(path) == path:
+            return get_pythonpath(os.path.dirname(path))
+        else:
+            return ''
+    else:
+        paths = [path]
+        additional = [os.path.join(path, p) for p in['src', 'lib', 'test']]
+        parent = os.path.dirname(path)
+        additional = [os.path.join(parent, p) for p in['src', 'lib', 'test']]
+        paths += [p for p in additional if os.path.isdir(p)]
+        return ':'.join(paths)
+
+
 def run_cmd(paths, args):
+    '''main function'''
     if args.show_plugins is True:
         print('\n'.join(PLUGINS.keys()))
         return 0
@@ -308,6 +345,12 @@ def run_cmd(paths, args):
 
     issues = []
     for path in paths:
+        if not os.path.exists(path):
+            print('Ignoring argument that does not exist: %s' % path)
+            continue
+        # PYTHONPATH for path
+        args.pythonpath = get_pythonpath(os.path.abspath(path))
+
         if args.debug:
             print('linting from %s' % path)
             print('Activated plugins %s' % args.selected_plugins.keys())
@@ -327,7 +370,7 @@ def run_cmd(paths, args):
                 ignoreddirs = []
                 for dirname in subdirs:
                     if (dirname in ['build', '.svn', 'CVS', '.hg', '.git']
-                        or 'egg-info' in dirname):
+                            or 'egg-info' in dirname):
 
                         ignoreddirs.append(dirname)
                 for dirname in ignoreddirs:
@@ -363,52 +406,68 @@ def run_cmd(paths, args):
 
 
 def get_unilint_parser(description=None):
+    '''Adds all options and arguments'''
     parser = ArgumentParser(description=description)
-    parser.add_argument('path', nargs='*',
-                        help='a folder or filename to check')
-    parser.add_argument("-v", "--verbose", dest="verbose", default=False,
-                        help="verbose output.",
-                        action="store_true")
-    parser.add_argument("--version", dest="version", default=False,
-                        help="print version and meta information",
-                        action="store_true")
-    parser.add_argument("--debug", dest="debug", default=False,
-                        help="debug output.",
-                        action="store_true")
-    parser.add_argument("-l", "--level", dest="level", default=LEVEL_ERROR,
-                        help="A number or one of %s." %
-                        (','.join(["%s(=%s)" % (k, v) for k, v in LEVELS.items()])),
-                        action="store")
-    parser.add_argument("-p", "--plugins", dest="show_plugins", default=False,
-                        help="List Available plugins",
-                        action="store_true")
-    parser.add_argument("-s", "--select-plugins", dest="selected_plugins", default=None,
-                        help="Choose plugins by comma separated id, all others deselected",
-                        action="store")
-    parser.add_argument("-d", "--deselect-plugins", dest="deselected_plugins", default=None,
-                        help="Choose plugins by comma separated id, ignored with --select-plugins",
-                        action="store")
-    parser.add_argument("-t", "--tests", dest="check_tests", default=False,
-                        help="Also check unit tests",
-                        action="store_true")
-    parser.add_argument("--docs", dest="check_docs", default=False,
-                        help="Also check doc files",
-                        action="store_true")
-    parser.add_argument("-g", "--generated", dest="check_generated", default=False,
-                        help="Also check generated Files",
-                        action="store_true")
-    parser.add_argument("--format", dest="format", default=None,
-                        help="Custom line format using flags %s" % ','.join(FLAGS),
-                        action="store")
-    parser.add_argument("-f", "--formatter", dest="formatter", default="brief",
-                        help="One of: %s" % ','.join(FORMATTERS.keys()),
-                        action="store")
-    parser.add_argument("-o", "--ordered", dest="ordered", default=False,
-                        help="Orders issues by file and line",
-                        action="store_true")
-    parser.add_argument("-r", "--raw", dest="raw", default=False,
-                        help="Just prints the output of the checker as is",
-                        action="store_true")
+    parser.add_argument(
+        'path', nargs='*',
+        help='a folder or filename to check')
+    parser.add_argument(
+        "-v", "--verbose", dest="verbose", default=False,
+        help="verbose output.",
+        action="store_true")
+    parser.add_argument(
+        "--version", dest="version", default=False,
+        help="print version and meta information",
+        action="store_true")
+    parser.add_argument(
+        "--debug", dest="debug", default=False,
+        help="debug output.",
+        action="store_true")
+    parser.add_argument(
+        "-l", "--level", dest="level", default=LEVEL_ERROR,
+        help="A number or one of %s." %
+        (','.join(["%s(=%s)" % (k, v) for k, v in LEVELS.items()])),
+        action="store")
+    parser.add_argument(
+        "-p", "--plugins", dest="show_plugins", default=False,
+        help="List Available plugins",
+        action="store_true")
+    parser.add_argument(
+        "-s", "--select-plugins", dest="selected_plugins", default=None,
+        help="Choose plugins by comma separated id, all others deselected",
+        action="store")
+    parser.add_argument(
+        "-d", "--deselect-plugins", dest="deselected_plugins", default=None,
+        help="Choose plugins by comma separated id, unless selected",
+        action="store")
+    parser.add_argument(
+        "-t", "--tests", dest="check_tests", default=False,
+        help="Also check unit tests",
+        action="store_true")
+    parser.add_argument(
+        "--docs", dest="check_docs", default=False,
+        help="Also check doc files",
+        action="store_true")
+    parser.add_argument(
+        "-g", "--generated", dest="check_generated", default=False,
+        help="Also check generated Files",
+        action="store_true")
+    parser.add_argument(
+        "--format", dest="format", default=None,
+        help="Custom line format using flags %s" % ','.join(FLAGS),
+        action="store")
+    parser.add_argument(
+        "-f", "--formatter", dest="formatter", default="brief",
+        help="One of: %s" % ','.join(FORMATTERS.keys()),
+        action="store")
+    parser.add_argument(
+        "-o", "--ordered", dest="ordered", default=False,
+        help="Orders issues by file and line",
+        action="store_true")
+    parser.add_argument(
+        "-r", "--raw", dest="raw", default=False,
+        help="Just prints the output of the checker as is",
+        action="store_true")
     return parser
 
 
@@ -434,6 +493,24 @@ def evaluate_options(args):
         else:
             args.level = LEVELS[args.level]
 
+    # LOGGING
+    logoutput = logging.StreamHandler()
+    logoutput.propagate = False
+    logoutput.setLevel(logging.NOTSET)
+    log = logging.getLogger(__package__)
+    log.handlers = []
+    log.propagate = False
+    log.addHandler(logoutput)
+
+    if args.debug:
+        formatter = logging.Formatter(
+            '[%(asctime)s-%(name)s]%(levelname)s: %(message)s')
+        logoutput.setFormatter(formatter)
+        log.setLevel(logging.DEBUG)
+        log.debug('Debug log enabled')
+    elif args.verbose:
+        log.setLevel(logging.INFO)
+
     return args, paths
 
 
